pub struct Plane {
pub normal: Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>,
pub d: f32,
}Fields
normal: Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>d: f32Implementations
sourceimpl Plane
impl Plane
sourcepub fn from_normal_and_point(
normal: &Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>,
point: &Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>
) -> Option<Plane>
pub fn from_normal_and_point( normal: &Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>, point: &Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>> ) -> Option<Plane>
Creates plane from a point and normal vector at that point. May fail if normal is degenerated vector.
sourcepub fn from_abcd(a: f32, b: f32, c: f32, d: f32) -> Option<Plane>
pub fn from_abcd(a: f32, b: f32, c: f32, d: f32) -> Option<Plane>
Creates plane using coefficients of plane equation Ax + By + Cz + D = 0 May fail if length of normal vector is zero (normal is degenerated vector).
pub fn dot( &self, point: &Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>> ) -> f32
pub fn distance( &self, point: &Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>> ) -> f32
sourcepub fn intersection_point(
&self,
b: &Plane,
c: &Plane
) -> Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>
pub fn intersection_point( &self, b: &Plane, c: &Plane ) -> Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>