Enum fyrox::core::notify::event::ModifyKind
pub enum ModifyKind {
Any,
Data(DataChange),
Metadata(MetadataKind),
Name(RenameMode),
Other,
}Expand description
An event describing mutation of content, name, or metadata.
Variants
Any
The catch-all case, to be used when the specific kind of event is unknown.
Data(DataChange)
An event emitted when the data content of a file is changed.
Metadata(MetadataKind)
An event emitted when the metadata of a file or folder is changed.
Name(RenameMode)
An event emitted when the name of a file or folder is changed.
Other
An event which specific kind is known but cannot be represented otherwise.