pub struct ViewStorageMut<'a, T, R, C, RStride, CStride>where
R: Dim,
C: Dim,
RStride: Dim,
CStride: Dim,{ /* private fields */ }Expand description
A mutable matrix data storage for mutable matrix view. Only contains an internal mutable reference to another matrix data storage.
Implementations
sourceimpl<'a, T, R, C, RStride, CStride> ViewStorageMut<'a, T, R, C, RStride, CStride>where
R: Dim,
C: Dim,
RStride: Dim,
CStride: Dim,
impl<'a, T, R, C, RStride, CStride> ViewStorageMut<'a, T, R, C, RStride, CStride>where R: Dim, C: Dim, RStride: Dim, CStride: Dim,
sourcepub unsafe fn from_raw_parts(
ptr: *mut T,
shape: (R, C),
strides: (RStride, CStride)
) -> ViewStorageMut<'a, T, R, C, RStride, CStride>where
RStride: Dim,
CStride: Dim,
pub unsafe fn from_raw_parts( ptr: *mut T, shape: (R, C), strides: (RStride, CStride) ) -> ViewStorageMut<'a, T, R, C, RStride, CStride>where RStride: Dim, CStride: Dim,
Create a new matrix view without bounds checking and from a raw pointer.
sourceimpl<'a, T, R, C> ViewStorageMut<'a, T, R, C, Dyn, Dyn>where
R: Dim,
C: Dim,
impl<'a, T, R, C> ViewStorageMut<'a, T, R, C, Dyn, Dyn>where R: Dim, C: Dim,
sourcepub unsafe fn new_unchecked<RStor, CStor, S>(
storage: &'a mut S,
start: (usize, usize),
shape: (R, C)
) -> ViewStorageMut<'a, T, R, C, <S as RawStorage<T, RStor, CStor>>::RStride, <S as RawStorage<T, RStor, CStor>>::CStride>where
RStor: Dim,
CStor: Dim,
S: RawStorageMut<T, RStor, CStor>,
pub unsafe fn new_unchecked<RStor, CStor, S>( storage: &'a mut S, start: (usize, usize), shape: (R, C) ) -> ViewStorageMut<'a, T, R, C, <S as RawStorage<T, RStor, CStor>>::RStride, <S as RawStorage<T, RStor, CStor>>::CStride>where RStor: Dim, CStor: Dim, S: RawStorageMut<T, RStor, CStor>,
Create a new matrix view without bounds checking.
sourcepub unsafe fn new_with_strides_unchecked<S, RStor, CStor, RStride, CStride>(
storage: &'a mut S,
start: (usize, usize),
shape: (R, C),
strides: (RStride, CStride)
) -> ViewStorageMut<'a, T, R, C, RStride, CStride>where
RStor: Dim,
CStor: Dim,
S: RawStorageMut<T, RStor, CStor>,
RStride: Dim,
CStride: Dim,
pub unsafe fn new_with_strides_unchecked<S, RStor, CStor, RStride, CStride>( storage: &'a mut S, start: (usize, usize), shape: (R, C), strides: (RStride, CStride) ) -> ViewStorageMut<'a, T, R, C, RStride, CStride>where RStor: Dim, CStor: Dim, S: RawStorageMut<T, RStor, CStor>, RStride: Dim, CStride: Dim,
Create a new matrix view without bounds checking.
sourceimpl<'a, T, R, C, RStride, CStride> ViewStorageMut<'a, T, R, C, RStride, CStride>where
R: Dim,
C: Dim,
RStride: Dim,
CStride: Dim,
ViewStorageMut<'a, T, R, C, RStride, CStride>: RawStorage<T, R, C> + IsContiguous,
impl<'a, T, R, C, RStride, CStride> ViewStorageMut<'a, T, R, C, RStride, CStride>where R: Dim, C: Dim, RStride: Dim, CStride: Dim, ViewStorageMut<'a, T, R, C, RStride, CStride>: RawStorage<T, R, C> + IsContiguous,
sourcepub fn into_slice(self) -> &'a [T]
pub fn into_slice(self) -> &'a [T]
Extracts the original slice from this storage.
sourceimpl<'a, T, R, C, RStride, CStride> ViewStorageMut<'a, T, R, C, RStride, CStride>where
T: Scalar,
R: Dim,
C: Dim,
RStride: Dim,
CStride: Dim,
ViewStorageMut<'a, T, R, C, RStride, CStride>: RawStorageMut<T, R, C> + IsContiguous,
impl<'a, T, R, C, RStride, CStride> ViewStorageMut<'a, T, R, C, RStride, CStride>where T: Scalar, R: Dim, C: Dim, RStride: Dim, CStride: Dim, ViewStorageMut<'a, T, R, C, RStride, CStride>: RawStorageMut<T, R, C> + IsContiguous,
sourcepub fn into_slice_mut(self) -> &'a mut [T]
pub fn into_slice_mut(self) -> &'a mut [T]
Extracts the original slice from this storage