pub struct LogMessage {
pub kind: MessageKind,
pub content: String,
pub time: Duration,
}Expand description
A message that could be sent by the logger to all listeners.
Fields
kind: MessageKindKind of the message: information, warning or error.
content: StringThe source message without logger prefixes.
time: DurationTime point at which the message was recorded. It is relative to the moment when the logger was initialized.