Struct fyrox::gui::core::notify::PollWatcher

pub struct PollWatcher { /* private fields */ }
Polling based Watcher implementation.

By default scans through all files and checks for changed entries based on their change date. Can also be changed to perform file content change checks.

See Config for more details.

Implementations



impl PollWatcher

pub fn new<F>(event_handler: F, config: Config) -> Result<PollWatcher, Error>where F: EventHandler,

Create a new PollWatcher, configured as needed.

pub fn poll(&self) -> Result<(), Error>

Actively poll for changes. Can be combined with a timeout of 0 to perform only manual polling.

pub fn with_initial_scan<F, G>( event_handler: F, config: Config, scan_callback: G ) -> Result<PollWatcher, Error>where F: EventHandler, G: ScanEventHandler,

Create a new PollWatcher with an scan event handler.

scan_fallback is called on the initial scan with all files seen by the pollwatcher.