pub struct InheritableVariable<T> { /* private fields */ }Expand description
A wrapper for a variable that hold additional flag that tells that initial value was changed in runtime.
InheritableVariables are used for resource inheritance system. Resource inheritance may just sound weird, but the idea behind it is very simple - take property values from parent resource if the value in current hasn’t changed in runtime.
To get better understanding, let’s look at very simple example. Imagine you have a scene with a 3d model instance. Now you realizes that the 3d model has a misplaced object and you need to fix it, you open a 3D modelling software (Blender, 3Ds max, etc) and move the object to a correct spot and re-save the 3D model. The question is: what should happen with the instance of the object in the scene? Logical answer would be: if it hasn’t been modified, then just take the new position from the 3D model. This is where inheritable variable comes into play. If you’ve change the value of such variable, it will remember changes and the object will stay on its new position instead of changed.
Deref and DerefMut
Access via Deref provides access to inner variable. DerefMut marks variable as modified and returns a mutable reference to inner variable.
Implementations
sourceimpl<T> InheritableVariable<T>where
T: Clone,
impl<T> InheritableVariable<T>where T: Clone,
sourcepub fn clone_inner(&self) -> T
pub fn clone_inner(&self) -> T
Clones wrapped value.
sourcepub fn try_sync_model<S>(&self, setter: S) -> boolwhere
S: FnOnce(T),
pub fn try_sync_model<S>(&self, setter: S) -> boolwhere S: FnOnce(T),
Tries to sync a value in a data model with a value in the inheritable variable. The value will be synced only if it was marked as needs sync.
sourceimpl<T> InheritableVariable<T>
impl<T> InheritableVariable<T>
sourcepub fn new_modified(value: T) -> InheritableVariable<T>
pub fn new_modified(value: T) -> InheritableVariable<T>
Creates new modified variable from given value. This method should always be used to create inheritable variables in the engine.
sourcepub fn new_non_modified(value: T) -> InheritableVariable<T>
pub fn new_non_modified(value: T) -> InheritableVariable<T>
Creates new variable without any flags set.
sourcepub fn new_with_flags(value: T, flags: VariableFlags) -> InheritableVariable<T>
pub fn new_with_flags(value: T, flags: VariableFlags) -> InheritableVariable<T>
Creates new variable from a given value with custom flags.
sourcepub fn set_value_and_mark_modified(&mut self, value: T) -> T
pub fn set_value_and_mark_modified(&mut self, value: T) -> T
Replaces value and also raises the VariableFlags::MODIFIED flag.
sourcepub fn set_value_with_flags(&mut self, value: T, flags: VariableFlags) -> T
pub fn set_value_with_flags(&mut self, value: T, flags: VariableFlags) -> T
Replaces value and flags.
sourcepub fn set_value_silent(&mut self, value: T) -> T
pub fn set_value_silent(&mut self, value: T) -> T
Replaces current value without marking the variable modified.
sourcepub fn need_sync(&self) -> bool
pub fn need_sync(&self) -> bool
Returns true if the respective data model’s variable must be synced.
sourcepub fn get_value_ref(&self) -> &T
pub fn get_value_ref(&self) -> &T
Returns a reference to the wrapped value.
sourcepub fn get_value_mut_and_mark_modified(&mut self) -> &mut T
pub fn get_value_mut_and_mark_modified(&mut self) -> &mut T
Returns a mutable reference to the wrapped value.
Important notes.
The method raises modified flag, no matter if actual modification was made!
sourcepub fn get_value_mut_silent(&mut self) -> &mut T
pub fn get_value_mut_silent(&mut self) -> &mut T
Returns a mutable reference to the wrapped value.
Important notes.
This method does not mark the value as modified!
sourcepub fn is_modified(&self) -> bool
pub fn is_modified(&self) -> bool
Returns true if variable was modified and should not be overwritten during property inheritance.
sourcepub fn mark_modified(&mut self)
pub fn mark_modified(&mut self)
Marks value as modified, so its value won’t be overwritten during property inheritance.