Struct fyrox::gui::expander::ExpanderBuilder
source · pub struct ExpanderBuilder {
pub widget_builder: WidgetBuilder,
/* private fields */
}Expand description
Expander builder allows you to create Expander widgets and add them to user interface.
Fields
widget_builder: WidgetBuilderBase builder.
Implementations
sourceimpl ExpanderBuilder
impl ExpanderBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> ExpanderBuilder
pub fn new(widget_builder: WidgetBuilder) -> ExpanderBuilder
Creates a new expander builder.
sourcepub fn with_header(self, header: Handle<UiNode>) -> ExpanderBuilder
pub fn with_header(self, header: Handle<UiNode>) -> ExpanderBuilder
Sets the desired header of the expander.
sourcepub fn with_content(self, content: Handle<UiNode>) -> ExpanderBuilder
pub fn with_content(self, content: Handle<UiNode>) -> ExpanderBuilder
Sets the desired content of the expander.
sourcepub fn with_expanded(self, expanded: bool) -> ExpanderBuilder
pub fn with_expanded(self, expanded: bool) -> ExpanderBuilder
Sets the desired state of the expander.
sourcepub fn with_checkbox(self, check_box: Handle<UiNode>) -> ExpanderBuilder
pub fn with_checkbox(self, check_box: Handle<UiNode>) -> ExpanderBuilder
Sets the desired check box (arrow part) of the expander.
sourcepub fn with_expander_column(
self,
expander_column: GridDimension
) -> ExpanderBuilder
pub fn with_expander_column( self, expander_column: GridDimension ) -> ExpanderBuilder
Sets the desired expander column properties of the expander.
sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
Finishes widget building and adds it to the user interface, returning a handle to the new instance.