Enum fyrox::gui::key::KeyBindingEditorMessage
source · pub enum KeyBindingEditorMessage {
Value(KeyBinding),
}Expand description
A set of messages, that is used to modify KeyBindingEditor state or to listen to its changes.
Variants
Value(KeyBinding)
A message, that is used to fetch a new value of a key binding, or to set new one.
Implementations
sourceimpl KeyBindingEditorMessage
impl KeyBindingEditorMessage
sourcepub fn value(
destination: Handle<UiNode>,
direction: MessageDirection,
value: KeyBinding
) -> UiMessage
pub fn value( destination: Handle<UiNode>, direction: MessageDirection, value: KeyBinding ) -> UiMessage
Creates KeyBindingEditorMessage::Value message.