Struct fyrox::gui::key::HotKeyEditorBuilder
source · pub struct HotKeyEditorBuilder { /* private fields */ }Expand description
Hot key editor builder creates HotKeyEditor widget instances and adds them to the user interface.
Implementations
sourceimpl HotKeyEditorBuilder
impl HotKeyEditorBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> HotKeyEditorBuilder
pub fn new(widget_builder: WidgetBuilder) -> HotKeyEditorBuilder
Creates a new hot key editor builder.
sourcepub fn with_value(self, hot_key: HotKey) -> HotKeyEditorBuilder
pub fn with_value(self, hot_key: HotKey) -> HotKeyEditorBuilder
Sets the desired default value of the hot key editor.
sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
Finishes widget building and adds it to the user interface, returning a handle to the new instance.