Enum fyrox::gui::menu::MenuItemContent
source · pub enum MenuItemContent<'a, 'b> {
Text {
text: &'a str,
shortcut: &'b str,
icon: Handle<UiNode>,
arrow: bool,
},
Node(Handle<UiNode>),
}Expand description
Allows you to set a content of a menu item either from a pre-built “layout” with icon/text/shortcut/arrow or a custom widget.
Variants
Text
Fields

icon: Handle<UiNode>Icon of the menu item. Usually it is a crate::image::Image or crate::vector_image::VectorImage widget instance.
Quick-n-dirty way of building elements. It can cover most of use cases - it builds classic menu item:
_________________________
| | | | |
|icon| text |shortcut| > |
|____|______|________|___|
Node(Handle<UiNode>)
Allows to put any node into menu item. It allows to customize menu item how needed - i.e. put image in it, or other user control.
Implementations
sourceimpl<'a, 'b> MenuItemContent<'a, 'b>
impl<'a, 'b> MenuItemContent<'a, 'b>
sourcepub fn text_with_shortcut(
text: &'a str,
shortcut: &'b str
) -> MenuItemContent<'a, 'b>
pub fn text_with_shortcut( text: &'a str, shortcut: &'b str ) -> MenuItemContent<'a, 'b>
Creates a menu item content with a text, a shortcut and an arrow (with no icon).
sourcepub fn text(text: &'a str) -> MenuItemContent<'a, 'b>
pub fn text(text: &'a str) -> MenuItemContent<'a, 'b>
Creates a menu item content with a text and an arrow (with no icon or shortcut).
sourcepub fn text_no_arrow(text: &'a str) -> MenuItemContent<'a, 'b>
pub fn text_no_arrow(text: &'a str) -> MenuItemContent<'a, 'b>
Creates a menu item content with a text only (with no icon, shortcut, arrow).