Struct fyrox::gui::text_box::TextBoxBuilder
source · pub struct TextBoxBuilder { /* private fields */ }Expand description
Text box builder creates new TextBox instances and adds them to the user interface.
Implementations
sourceimpl TextBoxBuilder
impl TextBoxBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> TextBoxBuilder
pub fn new(widget_builder: WidgetBuilder) -> TextBoxBuilder
Creates new text box widget builder with the base widget builder specified.
sourcepub fn with_font(self, font: SharedFont) -> TextBoxBuilder
pub fn with_font(self, font: SharedFont) -> TextBoxBuilder
Sets the desired font of the text box.
sourcepub fn with_text<P>(self, text: P) -> TextBoxBuilderwhere
P: AsRef<str>,
pub fn with_text<P>(self, text: P) -> TextBoxBuilderwhere P: AsRef<str>,
Sets the desired text of the text box.
sourcepub fn with_caret_brush(self, brush: Brush) -> TextBoxBuilder
pub fn with_caret_brush(self, brush: Brush) -> TextBoxBuilder
Sets the desired caret brush of the text box.
sourcepub fn with_selection_brush(self, brush: Brush) -> TextBoxBuilder
pub fn with_selection_brush(self, brush: Brush) -> TextBoxBuilder
Sets the desired selection brush of the text box.
sourcepub fn with_filter(
self,
filter: Rc<RefCell<dyn FnMut(char) -> bool>>
) -> TextBoxBuilder
pub fn with_filter( self, filter: Rc<RefCell<dyn FnMut(char) -> bool>> ) -> TextBoxBuilder
Sets the desired character filter of the text box. See FilterCallback for more info.
sourcepub fn with_vertical_text_alignment(
self,
alignment: VerticalAlignment
) -> TextBoxBuilder
pub fn with_vertical_text_alignment( self, alignment: VerticalAlignment ) -> TextBoxBuilder
Sets the desired vertical text alignment of the text box.
sourcepub fn with_horizontal_text_alignment(
self,
alignment: HorizontalAlignment
) -> TextBoxBuilder
pub fn with_horizontal_text_alignment( self, alignment: HorizontalAlignment ) -> TextBoxBuilder
Sets the desired horizontal text alignment of the text box.
sourcepub fn with_wrap(self, wrap: WrapMode) -> TextBoxBuilder
pub fn with_wrap(self, wrap: WrapMode) -> TextBoxBuilder
Sets the desired word wrapping of the text box.
sourcepub fn with_text_commit_mode(self, mode: TextCommitMode) -> TextBoxBuilder
pub fn with_text_commit_mode(self, mode: TextCommitMode) -> TextBoxBuilder
Sets the desired text commit mode of the text box.
sourcepub fn with_multiline(self, multiline: bool) -> TextBoxBuilder
pub fn with_multiline(self, multiline: bool) -> TextBoxBuilder
Enables or disables multiline mode of the text box.
sourcepub fn with_editable(self, editable: bool) -> TextBoxBuilder
pub fn with_editable(self, editable: bool) -> TextBoxBuilder
Enables or disables editing of the text box.
sourcepub fn with_mask_char(self, mask_char: Option<char>) -> TextBoxBuilder
pub fn with_mask_char(self, mask_char: Option<char>) -> TextBoxBuilder
Sets the desired masking character of the text box.
sourcepub fn with_shadow(self, shadow: bool) -> TextBoxBuilder
pub fn with_shadow(self, shadow: bool) -> TextBoxBuilder
Whether the shadow enabled or not.
sourcepub fn with_shadow_brush(self, brush: Brush) -> TextBoxBuilder
pub fn with_shadow_brush(self, brush: Brush) -> TextBoxBuilder
Sets desired shadow brush. It will be used to render the shadow.
sourcepub fn with_shadow_dilation(self, thickness: f32) -> TextBoxBuilder
pub fn with_shadow_dilation(self, thickness: f32) -> TextBoxBuilder
Sets desired shadow dilation in units. Keep in mind that the dilation is absolute, not percentage-based.
sourcepub fn with_shadow_offset(
self,
offset: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>>
) -> TextBoxBuilder
pub fn with_shadow_offset( self, offset: Matrix<f32, Const<2>, Const<1>, ArrayStorage<f32, 2, 1>> ) -> TextBoxBuilder
Sets desired shadow offset in units.
sourcepub fn with_skip_chars(self, chars: Vec<char>) -> TextBoxBuilder
pub fn with_skip_chars(self, chars: Vec<char>) -> TextBoxBuilder
Sets desired set of characters that will be treated like whitespace during Ctrl+Arrow navigation
(Ctrl+Left Arrow and Ctrl+Right Arrow). This could be useful to treat underscores like whitespaces,
which in its turn could be useful for in-game consoles where commands usually separated using
underscores (like_this_one).