Struct fyrox::renderer::Statistics
source · pub struct Statistics {
pub pipeline: PipelineStatistics,
pub lighting: LightingStatistics,
pub geometry: RenderPassStatistics,
pub pure_frame_time: f32,
pub capped_frame_time: f32,
pub frames_per_second: usize,
/* private fields */
}Expand description
Renderer statistics for one frame, also includes current frames per second amount.
Fields
pipeline: PipelineStatisticsShows how many pipeline state changes was made per frame.
lighting: LightingStatisticsShows how many lights and shadow maps were rendered.
geometry: RenderPassStatisticsShows how many draw calls was made and how many triangles were rendered.
pure_frame_time: f32Real time consumed to render frame. Time given in seconds.
capped_frame_time: f32Total time renderer took to process single frame, usually includes time renderer spend to wait to buffers swap (can include vsync). Time given in seconds.
frames_per_second: usizeTotal amount of frames been rendered in one second.