Type Alias fyrox::resource::model::ModelResource
source · pub type ModelResource = Resource<Model>;Expand description
Type alias for model resources.
Aliased Type
struct ModelResource { /* private fields */ }Trait Implementations
sourceimpl ModelResourceExtension for ModelResource
impl ModelResourceExtension for ModelResource
sourcefn instantiate_from(
model: ModelResource,
model_data: &Model,
handle: Handle<Node>,
dest_graph: &mut Graph
) -> (Handle<Node>, NodeHandleMap)
fn instantiate_from( model: ModelResource, model_data: &Model, handle: Handle<Node>, dest_graph: &mut Graph ) -> (Handle<Node>, NodeHandleMap)
Tries to instantiate model from given resource.
sourcefn instantiate(&self, dest_scene: &mut Scene) -> Handle<Node>
fn instantiate(&self, dest_scene: &mut Scene) -> Handle<Node>
Tries to instantiate model from given resource.
sourcefn instantiate_at(
&self,
scene: &mut Scene,
position: Vector3<f32>,
orientation: UnitQuaternion<f32>
) -> Handle<Node>
fn instantiate_at( &self, scene: &mut Scene, position: Vector3<f32>, orientation: UnitQuaternion<f32> ) -> Handle<Node>
Instantiates a prefab and places it at specified position and orientation in global coordinates.
sourcefn retarget_animations_directly(
&self,
root: Handle<Node>,
graph: &Graph
) -> Vec<Animation>
fn retarget_animations_directly( &self, root: Handle<Node>, graph: &Graph ) -> Vec<Animation>
Tries to retarget animations from given model resource to a node hierarchy starting
from
root on a given scene. Read moresourcefn retarget_animations_to_player(
&self,
root: Handle<Node>,
dest_animation_player: Handle<Node>,
graph: &mut Graph
) -> Vec<Handle<Animation>>
fn retarget_animations_to_player( &self, root: Handle<Node>, dest_animation_player: Handle<Node>, graph: &mut Graph ) -> Vec<Handle<Animation>>
Tries to retarget animations from given model resource to a node hierarchy starting
from
root on a given scene. Unlike Self::retarget_animations_directly, it automatically
adds retargetted animations to the specified animation player in the hierarchy of given root. Read moresourcefn retarget_animations(
&self,
root: Handle<Node>,
graph: &mut Graph
) -> Vec<Handle<Animation>>
fn retarget_animations( &self, root: Handle<Node>, graph: &mut Graph ) -> Vec<Handle<Animation>>
Tries to retarget animations from given model resource to a node hierarchy starting
from
root on a given scene. Unlike Self::retarget_animations_directly, it automatically
adds retargetted animations to a first animation player in the hierarchy of given root. Read more