#[repr(u32)]
pub enum CompressionOptions { NoCompression = 0, Speed = 1, Quality = 2, }
Texture compression options.

Notes

Try to avoid using compression for normal maps, normals maps usually has smooth gradients, but compression algorithms used by Fyrox cannot preserve good quality of such gradients.

Variants



NoCompression = 0

An image will be stored without compression if it is not already compressed.



Speed = 1

An image will be encoded via DXT1 (BC1) compression with low quality if is not already compressed. Compression ratio is 1:8 (without alpha) or 1:6 (with 1-bit alpha). This option provides maximum speed by having lowest requirements of memory bandwidth.



Quality = 2

An image will be encoded via DXT5 (BC5) compression with high quality if it is not already compressed. Compression ratio is 1:4 (including alpha) This option is faster than NoCompression speed by lower requirements of memory bandwidth.