Enum fyrox::resource::texture::TexturePixelKind
source · #[repr(u32)]pub enum TexturePixelKind {
Show 25 variants
R8 = 0,
RGB8 = 1,
RGBA8 = 2,
RG8 = 3,
R16 = 4,
RG16 = 5,
BGR8 = 6,
BGRA8 = 7,
RGB16 = 8,
RGBA16 = 9,
DXT1RGB = 10,
DXT1RGBA = 11,
DXT3RGBA = 12,
DXT5RGBA = 13,
R8RGTC = 14,
RG8RGTC = 15,
RGB32F = 16,
RGBA32F = 17,
Luminance8 = 18,
LuminanceAlpha8 = 19,
Luminance16 = 20,
LuminanceAlpha16 = 21,
RGB16F = 22,
R32F = 23,
R16F = 24,
}Expand description
Texture kind defines pixel format of texture.
Variants
R8 = 0
1 byte red.
RGB8 = 1
Red, green, and blue components, each by 1 byte.
RGBA8 = 2
Red, green, blue, and alpha components, each by 1 byte.
RG8 = 3
Red and green, each by 1 byte.
R16 = 4
2 byte red.
RG16 = 5
Red and green, each by 2 byte.
BGR8 = 6
Blue, green, and red components, each by 1 byte.
BGRA8 = 7
Blue, green, red and alpha components, each by 1 byte.
RGB16 = 8
Red, green, and blue components, each by 2 byte.
RGBA16 = 9
Red, green, blue, and alpha components, each by 2 byte.
DXT1RGB = 10
Compressed S3TC DXT1 RGB (no alpha).
DXT1RGBA = 11
Compressed S3TC DXT1 RGBA.
DXT3RGBA = 12
Compressed S3TC DXT3 RGBA.
DXT5RGBA = 13
Compressed S3TC DXT5 RGBA.
R8RGTC = 14
Compressed R8 texture (RGTC).
RG8RGTC = 15
Compressed RG8 texture (RGTC).
RGB32F = 16
Floating-point RGB texture with 32bit depth.
RGBA32F = 17
Floating-point RGBA texture with 32bit depth.
Luminance8 = 18
1 byte luminance texture where pixels will have (L, L, L, 1.0) value on fetching.
Platform-specific
- WebAssembly - not supported, the image will act like
Self::R8format, which will have (R, 0.0, 0.0, 1.0) pixels.
LuminanceAlpha8 = 19
1 byte for luminance and 1 for alpha, where all pixels will have (L, L, L, A) value on fetching.
Platform-specific
- WebAssembly - not supported, the image will act like
Self::RG8format, which will have (R, G, R, G) pixels.
Luminance16 = 20
2 byte luminance texture where pixels will have (L, L, L, 1.0) value on fetching.
Platform-specific
- WebAssembly - not supported, the image will act like
Self::R8format, which will have (R, 0.0, 0.0, 1.0) pixels.
LuminanceAlpha16 = 21
2 byte for luminance and 2 for alpha, where all pixels will have (L, L, L, A) value on fetching.
Platform-specific
- WebAssembly - not supported, the image will act like
Self::RG16format, which will have (R, G, R, G) pixels.
RGB16F = 22
Red, green, blue components, each by 2 byte half-precision float.
R32F = 23
Red component as 4-byte, medium-precision float.
R16F = 24
Red component as 2-byte, half-precision float.
Implementations
sourceimpl TexturePixelKind
impl TexturePixelKind
sourcepub fn size_in_bytes(&self) -> Option<usize>
pub fn size_in_bytes(&self) -> Option<usize>
Tries to get size of the pixel in bytes. Pixels of compressed textures consumes less than a byte, so
there’s no way to express their size on whole number of bytes, in this case None is returned.