pub struct NodeContainer(/* private fields */);
A wrapper for node pool record that allows to define custom visit method to have full control over instantiation process at deserialization.

Implementations

source

impl NodeContainer

source

pub const F_0: &'static str = "0"