pub struct ParticleSystemBuilder { /* private fields */ }Expand description
Particle system builder allows you to construct particle system in declarative manner. This is typical implementation of Builder pattern.
Implementations
Sourceimpl ParticleSystemBuilder
impl ParticleSystemBuilder
Sourcepub fn new(base_builder: BaseBuilder) -> ParticleSystemBuilder
pub fn new(base_builder: BaseBuilder) -> ParticleSystemBuilder
Creates new builder with default parameters.
Sourcepub fn with_emitters(self, emitters: Vec<Emitter>) -> ParticleSystemBuilder
pub fn with_emitters(self, emitters: Vec<Emitter>) -> ParticleSystemBuilder
Sets desired emitters for particle system.
Sourcepub fn with_material(
self,
material: Resource<Material>,
) -> ParticleSystemBuilder
pub fn with_material( self, material: Resource<Material>, ) -> ParticleSystemBuilder
Sets desired material for particle system.
Sourcepub fn with_acceleration(
self,
acceleration: Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>,
) -> ParticleSystemBuilder
pub fn with_acceleration( self, acceleration: Matrix<f32, Const<3>, Const<1>, ArrayStorage<f32, 3, 1>>, ) -> ParticleSystemBuilder
Sets desired acceleration for particle system.
Sourcepub fn with_visible_distance(self, distance: f32) -> ParticleSystemBuilder
pub fn with_visible_distance(self, distance: f32) -> ParticleSystemBuilder
Sets the desired visible distance for the particle system. See ParticleSystem::set_visible_distance
for more info.
Sourcepub fn with_color_over_lifetime_gradient(
self,
color_over_lifetime: ColorGradient,
) -> ParticleSystemBuilder
pub fn with_color_over_lifetime_gradient( self, color_over_lifetime: ColorGradient, ) -> ParticleSystemBuilder
Sets color gradient over lifetime for particle system.
Sourcepub fn with_particles(self, particles: Vec<Particle>) -> ParticleSystemBuilder
pub fn with_particles(self, particles: Vec<Particle>) -> ParticleSystemBuilder
Sets an initial set of particles that not belongs to any emitter. This method could be useful if you need a custom position/velocity/etc. of each particle.
Sourcepub fn with_playing(self, enabled: bool) -> ParticleSystemBuilder
pub fn with_playing(self, enabled: bool) -> ParticleSystemBuilder
Sets initial particle system state.
Sourcepub fn with_rng(self, rng: ParticleSystemRng) -> ParticleSystemBuilder
pub fn with_rng(self, rng: ParticleSystemRng) -> ParticleSystemBuilder
Sets desired pseudo-random numbers generator.
Sourcepub fn with_coordinate_system(
self,
coordinate_system: CoordinateSystem,
) -> ParticleSystemBuilder
pub fn with_coordinate_system( self, coordinate_system: CoordinateSystem, ) -> ParticleSystemBuilder
Sets the desired coordinate system for particles.
Sourcepub fn with_fadeout_margin(self, margin: f32) -> ParticleSystemBuilder
pub fn with_fadeout_margin(self, margin: f32) -> ParticleSystemBuilder
Sets a margin value in which the distance fading will occur.
Sourcepub fn build_node(self) -> Node
pub fn build_node(self) -> Node
Creates new instance of particle system.
Sourcepub fn build(self, graph: &mut Graph) -> Handle<ParticleSystem>
pub fn build(self, graph: &mut Graph) -> Handle<ParticleSystem>
Creates new instance of particle system and adds it to the graph.