Struct fyrox::scene::transform::TransformBuilder
source · pub struct TransformBuilder { /* private fields */ }Expand description
Transform builder allows you to construct transform in declarative manner. This is typical implementation of Builder pattern.
Implementations
sourceimpl TransformBuilder
impl TransformBuilder
sourcepub fn new() -> Self
pub fn new() -> Self
Creates new transform builder. If it won’t be modified then it will produce identity transform as result.
sourcepub fn with_local_scale(self, scale: Vector3<f32>) -> Self
pub fn with_local_scale(self, scale: Vector3<f32>) -> Self
Sets desired local scale.
sourcepub fn with_local_position(self, position: Vector3<f32>) -> Self
pub fn with_local_position(self, position: Vector3<f32>) -> Self
Sets desired local position.
sourcepub fn with_local_rotation(self, rotation: UnitQuaternion<f32>) -> Self
pub fn with_local_rotation(self, rotation: UnitQuaternion<f32>) -> Self
Sets desired local rotation.
sourcepub fn with_pre_rotation(self, rotation: UnitQuaternion<f32>) -> Self
pub fn with_pre_rotation(self, rotation: UnitQuaternion<f32>) -> Self
Sets desired pre-rotation.
sourcepub fn with_post_rotation(self, rotation: UnitQuaternion<f32>) -> Self
pub fn with_post_rotation(self, rotation: UnitQuaternion<f32>) -> Self
Sets desired post-rotation.
sourcepub fn with_rotation_offset(self, offset: Vector3<f32>) -> Self
pub fn with_rotation_offset(self, offset: Vector3<f32>) -> Self
Sets desired rotation offset.
sourcepub fn with_rotation_pivot(self, pivot: Vector3<f32>) -> Self
pub fn with_rotation_pivot(self, pivot: Vector3<f32>) -> Self
Sets desired rotation pivot.
sourcepub fn with_scaling_offset(self, offset: Vector3<f32>) -> Self
pub fn with_scaling_offset(self, offset: Vector3<f32>) -> Self
Sets desired scaling offset.
sourcepub fn with_scaling_pivot(self, pivot: Vector3<f32>) -> Self
pub fn with_scaling_pivot(self, pivot: Vector3<f32>) -> Self
Sets desired scaling pivot.