Struct fyrox::utils::astar::PathFinder
source · pub struct PathFinder { /* private fields */ }Expand description
See module docs.
Implementations
sourceimpl PathFinder
impl PathFinder
sourcepub fn set_vertices(&mut self, vertices: Vec<PathVertex>)
pub fn set_vertices(&mut self, vertices: Vec<PathVertex>)
Sets active set of vertices. Links between vertices must contain valid indices (which are not out-of-bounds), otherwise path from/to such vertices won’t be built.
sourcepub fn link_bidirect(&mut self, a: usize, b: usize)
pub fn link_bidirect(&mut self, a: usize, b: usize)
Creates bidirectional link between two vertices. Bidirectional means
that point a can be reached from point b as well as point b
can be reached from point a.
sourcepub fn link_unidirect(&mut self, a: usize, b: usize)
pub fn link_unidirect(&mut self, a: usize, b: usize)
Creates unidirectional link between vertex a and vertex b. Unidirectional
means that there is no direct link between b to a, only from a to b.
sourcepub fn vertex(&self, index: usize) -> Option<&PathVertex>
pub fn vertex(&self, index: usize) -> Option<&PathVertex>
Returns shared reference to a path vertex at the given index.
sourcepub fn vertex_mut(&mut self, index: usize) -> Option<&mut PathVertex>
pub fn vertex_mut(&mut self, index: usize) -> Option<&mut PathVertex>
Returns mutable reference to a path vertex at the given index.
sourcepub fn vertices(&self) -> &[PathVertex]
pub fn vertices(&self) -> &[PathVertex]
Returns reference to the array of vertices.
sourcepub fn vertices_mut(&mut self) -> &mut [PathVertex]
pub fn vertices_mut(&mut self) -> &mut [PathVertex]
Returns reference to the array of vertices.
sourcepub fn add_vertex(&mut self, vertex: PathVertex) -> u32
pub fn add_vertex(&mut self, vertex: PathVertex) -> u32
Adds a new vertex to the path finder.
sourcepub fn pop_vertex(&mut self) -> Option<PathVertex>
pub fn pop_vertex(&mut self) -> Option<PathVertex>
Removes last vertex from the graph. Automatically cleans “dangling” references to the deleted vertex from every other vertex in the graph and shifts indices of neighbour vertices, to preserve graph structure.
sourcepub fn remove_vertex(&mut self, index: usize) -> PathVertex
pub fn remove_vertex(&mut self, index: usize) -> PathVertex
Removes a vertex at the given index from the graph. Automatically cleans “dangling” references to the deleted vertex from every other vertex in the graph and shifts indices of neighbour vertices, to preserve graph structure.
sourcepub fn insert_vertex(&mut self, index: u32, vertex: PathVertex)
pub fn insert_vertex(&mut self, index: u32, vertex: PathVertex)
Inserts the vertex at the given index. Automatically shifts neighbour indices of every other vertex in the graph to preserve graph structure.
sourcepub fn build(
&mut self,
from: usize,
to: usize,
path: &mut Vec<Vector3<f32>>
) -> Result<PathKind, PathError>
pub fn build( &mut self, from: usize, to: usize, path: &mut Vec<Vector3<f32>> ) -> Result<PathKind, PathError>
Tries to build path from begin point to end point. Returns path kind:
- Full: there are direct path from begin to end.
- Partial: there are not direct path from begin to end, but it is closest.
- Empty: no path available - in most cases indicates some error in input params.
Notes
This is more or less naive implementation, it most certainly will be slower than specialized solutions.
sourcepub fn build_and_convert<F, T>(
&mut self,
from: usize,
to: usize,
path: &mut Vec<T>,
func: F
) -> Result<PathKind, PathError>where
F: FnMut(usize, &PathVertex) -> T,
pub fn build_and_convert<F, T>( &mut self, from: usize, to: usize, path: &mut Vec<T>, func: F ) -> Result<PathKind, PathError>where F: FnMut(usize, &PathVertex) -> T,
Tries to build path from begin point to end point. Returns path kind:
- Full: there are direct path from begin to end.
- Partial: there are not direct path from begin to end, but it is closest.
- Empty: no path available - in most cases indicates some error in input params.
Notes
This is more or less naive implementation, it most certainly will be slower than specialized solutions.