Enum fyrox::asset::state::ResourceState
source · pub enum ResourceState {
Pending {
path: PathBuf,
wakers: Vec<Waker>,
type_uuid: Uuid,
},
LoadError {
path: PathBuf,
error: Option<Arc<dyn ResourceLoadError>>,
type_uuid: Uuid,
},
Ok(Box<dyn ResourceData>),
}Expand description
Resource could be in three possible states:
- Pending - it is loading.
- LoadError - an error has occurred during the load.
- Ok - resource is fully loaded and ready to use.
Why it is so complex? Short answer: asynchronous loading. Long answer: when you loading a scene you expect it to be loaded as fast as possible, use all available power of the CPU. To achieve that each resource ideally should be loaded on separate core of the CPU, but since this is asynchronous, we must have the ability to track the state of the resource.
Variants
Pending
Fields
Resource is loading from external resource or in the queue to load.
LoadError
Fields
error: Option<Arc<dyn ResourceLoadError>>An error. This wrapped in Option only to be Default_ed.
An error has occurred during the load.
Ok(Box<dyn ResourceData>)
Actual resource data when it is fully loaded.
Implementations
sourceimpl ResourceState
impl ResourceState
sourcepub fn new_pending(path: PathBuf, type_uuid: Uuid) -> ResourceState
pub fn new_pending(path: PathBuf, type_uuid: Uuid) -> ResourceState
Creates new resource in pending state.
sourcepub fn new_load_error(
path: PathBuf,
error: Option<Arc<dyn ResourceLoadError>>,
type_uuid: Uuid
) -> ResourceState
pub fn new_load_error( path: PathBuf, error: Option<Arc<dyn ResourceLoadError>>, type_uuid: Uuid ) -> ResourceState
Creates new resource in error state.
sourcepub fn new_ok<T>(data: T) -> ResourceStatewhere
T: ResourceData,
pub fn new_ok<T>(data: T) -> ResourceStatewhere T: ResourceData,
Creates new resource in ok (resource with data) state.
sourcepub fn is_loading(&self) -> bool
pub fn is_loading(&self) -> bool
Checks whether the resource is still loading or not.
sourcepub fn switch_to_pending_state(&mut self)
pub fn switch_to_pending_state(&mut self)
Switches the internal state of the resource to ResourceState::Pending.
sourcepub fn commit(&mut self, state: ResourceState)
pub fn commit(&mut self, state: ResourceState)
Changes ResourceState::Pending state to ResourceState::Ok(data) with given data.
Additionally it wakes all futures.
sourcepub fn commit_ok<T>(&mut self, data: T)where
T: ResourceData,
pub fn commit_ok<T>(&mut self, data: T)where T: ResourceData,
Changes internal state to ResourceState::Ok
sourcepub fn commit_error<E>(&mut self, path: PathBuf, error: E)where
E: ResourceLoadError,
pub fn commit_error<E>(&mut self, path: PathBuf, error: E)where E: ResourceLoadError,
Changes internal state to ResourceState::LoadError.