#[repr(u32)]pub enum Mobility {
Static = 0,
Stationary = 1,
Dynamic = 2,
}Expand description
Mobility defines a group for scene node which has direct impact on performance and capabilities of nodes.
Variants
Static = 0
Transform cannot be changed.
Scene and performance.
Nodes with Static mobility should be used all the time you need unchangeable node. Such nodes will have maximum optimization during the rendering.
Meshes
Static meshes will be baked into larger blocks to reduce draw call count per frame. Also static meshes will participate in lightmap generation.
Lights
Static lights will be baked in lightmap. They lit only static geometry! Specular lighting is not supported.
Stationary = 1
Transform cannot be changed, but other node-dependent properties are changeable.
Scene and performance.
Meshes
Same as Static.
Lights
Stationary lights have complex route for shadows:
- Shadows from Static/Stationary meshes will be baked into lightmap.
- Shadows from Dynamic lights will be re-rendered each frame into shadow map. Stationary lights support specular lighting.
Dynamic = 2
Transform can be freely changed.
Scene and performance.
Dynamic mobility should be used only for the objects that are designed to be moving in the scene, for example - objects with physics, or dynamic lights, etc.